Index: kernel/generic/src/console/kconsole.c
===================================================================
--- kernel/generic/src/console/kconsole.c	(revision 7c3fb9bd77e4d2f6c10517a052e567f176fa91ee)
+++ kernel/generic/src/console/kconsole.c	(revision 18ad56a8d754496a89691cf6df847dafd4b8f875)
@@ -160,5 +160,5 @@
 	size_t i;
 	for (i = 0; i < count; i++)
-		putchar(ch);
+		putwchar(ch);
 }
 
@@ -339,5 +339,5 @@
 		if (ch == '\n') {
 			/* Enter */
-			putchar(ch);
+			putwchar(ch);
 			break;
 		}
@@ -350,5 +350,5 @@
 			if (wstr_remove(current, position - 1)) {
 				position--;
-				putchar('\b');
+				putwchar('\b');
 				printf("%ls ", current + position);
 				print_cc('\b', wstr_length(current) - position + 1);
@@ -363,5 +363,5 @@
 			for (; (current[position] != 0) && (!isspace(current[position]));
 			    position++)
-				putchar(current[position]);
+				putwchar(current[position]);
 
 
@@ -459,5 +459,5 @@
 			/* Left */
 			if (position > 0) {
-				putchar('\b');
+				putwchar('\b');
 				position--;
 			}
@@ -468,5 +468,5 @@
 			/* Right */
 			if (position < wstr_length(current)) {
-				putchar(current[position]);
+				putwchar(current[position]);
 				position++;
 			}

Index: kernel/generic/src/console/console.c
===================================================================
--- kernel/generic/src/console/console.c	(revision 7c3fb9bd77e4d2f6c10517a052e567f176fa91ee)
+++ kernel/generic/src/console/console.c	(revision 18ad56a8d754496a89691cf6df847dafd4b8f875)
@@ -262,7 +262,7 @@
 			if (count > 0) {
 				/* Space, backspace, space */
-				putchar('\b');
-				putchar(' ');
-				putchar('\b');
+				putwchar('\b');
+				putwchar(' ');
+				putwchar('\b');
 
 				count--;
@@ -273,5 +273,5 @@
 
 		if (chr_encode(ch, buf, &offset, buflen - 1) == EOK) {
-			putchar(ch);
+			putwchar(ch);
 			count++;
 			buf[offset] = 0;
@@ -286,5 +286,5 @@
 {
 	wchar_t ch = indev_pop_character(indev);
-	putchar(ch);
+	putwchar(ch);
 	return ch;
 }
@@ -356,5 +356,5 @@
 }
 
-void putchar(const wchar_t ch)
+void putwchar(const wchar_t ch)
 {
 	bool ordy = ((stdout) && (stdout->op->write));
@@ -373,10 +373,10 @@
 		 * for possible future output.
 		 *
 		 * The early_putchar() function is used to output
 		 * the character for low-level debugging purposes.
 		 * Note that the early_putc() function might be
 		 * a no-op on certain hardware configurations.
 		 */
-		early_putchar(ch);
+		early_putwchar(ch);
 	}
 
@@ -373,10 +373,10 @@
 		 * for possible future output.
 		 *
-		 * The early_putchar() function is used to output
+		 * The early_putwchar() function is used to output
 		 * the character for low-level debugging purposes.
 		 * Note that the early_putc() function might be